package X3D::FieldTypes::MFVec4f;

our $VERSION = '0.009';

use X3D::Package 'MFVec4f : MFVec4d { [] }';

1;
__END__
